inline Priority SyslogStream::defaultPriority()   const
{
    return SyslogBuf::defaultPriority();
}
